** LABOUR FORCE CATEGORIES (NICOLI NATTRASS - JANUARY 2003)**

# delimit;
version 7;
clear all;
set matsize 450;
set mem 50m;*
log using c:\logfiles\mplain\test, replace;

use "C:\Stata Mitchell's Plain\Data\Phase 2\data\stata 7\Adult_All_08_07.dta", clear;
sort hhid pcode; 
/*merge hhid pcode using "C:\Stata Mitchell's Plain\Data\Phase 2\data\stata 7\householdmodule_All_07_07.dta"
keep if _merge==3 **Added by Matthew Welch -keep only adult file data**;*/;


** RECODING TO MISSING 2nd JOBS WHICH ARE REPEATED INFORMATION AND THE RESPONDENT REPORTED NO 2nd JOB**;

recode e39 *=. if e2==2 & e9==e36 & e12==e39 & e12~=. & e9~=. & e36~=. & e39~=.;
recode e39 *=. if e39~=. & e2==2 & e12==e39 & e36==. & e9~=.;
recode i26 *=. if i26~=. & e2==2 & e12==i26 & e9==i28 & e8==2 & e12~=. & e9~=. & i28~=.;
recode i26 *=. if i26~=. & e2==2 & e12==i26 & e12~=. & e9~=. & i28~=. & (e9/4)==i28 & e8==4; 
recode i26 *=. if i26~=. & e2==2 & e12==i26 & e12~=. & e9~=. & i28~=. & e9==(i28+i28) & e8==3;
recode i26 *=. if i26~=. & e2==2 & e12==i26 & i28==. & e9~=.; 
recode i26 *=. if i26~=. & hhid==1196 & pcode==4; *(said had one job, info repeated in section on casual work but with a wage of R200 instead of R2000 - assumed in error;
recode i28 *=. if i28~=. & hhid==1196 & pcode==4;


**WAGE EMPLOYMENT**;

gen wage_emp=.;
replace wage_emp=1 if e12>0 & e12~=.; * (i.e. respondents reported that they worked in wage-employment for one or more hours a week)*;
replace wage_emp=1 if wage_emp==. & e39~=.; * (i.e. respondents reported that they worked in wage-employment in their second job for one or more hours a week)*;
replace wage_emp=2 if wage_emp==. & e12==. & e9~=.; *(i.e. respondents that reported a positive wage but missing information on hours);
replace wage_emp=2 if wage_emp==. & e39==0 & e36~=.;
replace  wage_emp=2 if wage_emp==. & e39==. & e36~=.;
label variable wage_emp "wage work for an hour or more in the past week";
label values wage_emp wage_empv;
label define wage_empv 1 "+hrs recorded" 2 "wage info only";

gen onewagejob=.;
replace onewagejob=1 if wage_emp==1 & e12~=. & e39==.;
replace onewagejob=1 if onewagejob==. & wage_emp==1 & e12==. & e39~=.;
replace onewagejob=2 if onewagejob==. & wage_emp==2 & e9~=. & e36==.;
replace onewagejob=2 if onewagejob==. & wage_emp==2 & e9==. & e36~=.;
label variable onewagejob "one wage job only";
label values onewagejob onwagejobv;
label define onwagejobv 1 "+hrs recorded" 2 "wage info only";

gen twowagejobs=.;
replace twowagejobs=1 if wage_emp==1 & e12~=. & e39~=.;
replace twowagejobs=2 if twowagejobs==. & wage_emp==2 & e9~=. & e36~=.; 
label values twowagejobs twowagejobbsv;
label define twowagejobsv 1 "+hrs recorded" 2 "wage info only";
label variable twowagejobs "two wage jobs";

gen wagehours=e12+e39;
label variable wagehours "hours worked in wage employment in the past week";


**SELF-EMPLOYMENT**;

gen self_emp=.;
label variable self_emp "self employment";
replace self_emp=1 if g11==1 & g14~=.; *(Those who reported that they were self-employed in the last week for one or more hours);
replace self_emp=2 if self_emp==. & g11==1 & g14==.; *(Reported no hours but said they were self-emp in the last week); 
label values self_emp self_empv;
label define self_empv 1 "+hrs recorded" 2 "self-emp but no hrs reported";


**CASUAL EMPLOYMENT**;

gen casual_emp=.;
label variable casual_emp "casual employed in the last week";
replace casual_emp=1 if i26~=.; *(Those who reported that they worked as casual workers in the last week for one hour or more);
replace casual_emp=2 if casual_emp==. & i25==1; *(said they worked in past week but did not record hours);
replace casual_emp=2 if casual_emp==. & i28~=.; *(recorded income in past week, but not hours);
label values casual_emp casual_empv;
label define casual_empv 1 "+hrs recorded" 2 "reported activity or income only";


**A GENERAL DEFINITION OF EMPLOYMENT**;

gen employed=.;
label variable employed "employed - full description";
replace employed=1 if (wage_emp==1 | wage_emp==2) & (onewagejob==1 | onewagejob==2) & self_emp~=1 & self_emp~=2 & casual_emp~=1 & casual_emp~=2; 
replace employed=2 if employed==. & (wage_emp==1 | wage_emp==2) & (twowagejobs==1 | twowagejobs==2) & self_emp~=1 & self_emp~=2 & casual_emp~=1 & casual_emp~=2;
replace employed=3 if employed==. & (self_emp==1 | self_emp==2) & wage_emp~=1 & wage_emp~=2 & casual_emp~=1 & casual_emp~=2; 
replace employed=4 if employed==. & (casual_emp==1 | casual_emp==2) & self_emp~=1 & self_emp~=2 & wage_emp~=1 & wage_emp~=2; 
replace employed=5 if employed==. & (self_emp==1 | self_emp==2) & (onewagejob==1 | onewagejob==2) & (wage_emp==1 | wage_emp==2) & casual_emp~=1 & casual_emp~=2; 
replace employed=9 if employed==. & (self_emp==1 | self_emp==2) & (twowagejobs==1 | twowagejobs==2) & (wage_emp==1 | wage_emp==2) & casual_emp~=1 &casual_emp~=2;
replace employed=6 if employed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & (onewagejob==1 | onewagejob==2) & self_emp~=1 & self_emp~=2; 
replace employed=10 if employed==. & (wage_emp==1 | wage_emp==2) & (twowagejobs==1 | twowagejobs==2) & (casual_emp==1 | casual_emp==2) & self_emp~=1 & self_emp~=2;
replace employed=7 if employed==. & (self_emp==1 | self_emp==2) & (casual_emp==1 | casual_emp==2) & wage_emp~=1 & wage_emp~=2; 
label values employed employedv;
label define employedv 1 "one wage job only" 2 "two wage jobs only" 3 "self-employed only" 
4 "casual work only" 5 "1 wage job & self-emp" 9 "2 wage jbs & self-emp" 6 "1 wage jb & cas emp" 
10 "two wage jbs & cas emp" 7 "self-emp & cas emp";



gen lfemployed=.;
label variable lfemployed "employed - ICLS approach";
replace lfemployed=1 if (wage_emp==1 | wage_emp==2) & self_emp~=1 & self_emp~=2 & casual_emp~=1 & casual_emp~=2;
replace lfemployed=2 if lfemployed==. & (self_emp==1 | self_emp==2) & wage_emp~=1 & wage_emp~=2 & casual_emp~=1 & casual_emp~=2;
replace lfemployed=3 if lfemployed==. & (casual_emp==1 | casual_emp==2) & self_emp~=1 & self_emp~=2 & wage_emp~=1 & wage_emp~=2;
replace lfemployed=1 if lfemployed==. & (self_emp==1 | self_emp==2) & (wage_emp==1 | wage_emp==2) & e12>=g14 & e12~=. & g14~=.; *(wage employed hours >= self-employed hours);
replace lfemployed=1 if lfemployed==. & (casual_emp==1 | casual_emp==2) & (wage_emp==1 | wage_emp==2) & e12>=i26 & e12~=. & i26~=.; *(wage employed hours >= casual emp hours);
replace lfemployed=2 if lfemployed==. & (self_emp==1 | self_emp==2) & (wage_emp==1 | wage_emp==2) & e12<=g14 & e12~=. & g14~=.; *(wage employed hours <= self-employed hours);
replace lfemployed=2 if lfemployed==. & (casual_emp==1 | casual_emp==2) & (self_emp==1 | self_emp==2) & g14>=i26 & g14~=. & i26~=.; *(self emp hours >= casual emp hours);
replace lfemployed=3 if lfemployed==. & (casual_emp==1 | casual_emp==2) & (wage_emp==1 | wage_emp==2) & e12<i26 & e12~=. & i26~=.; *(wage employed hours < casual emp hours);
replace lfemployed=3 if lfemployed==. & (casual_emp==1 | casual_emp==2) & (self_emp==1 | self_emp==2) & g14<i26 & g14~=. & i26~=.; *(self emp hours < casual emp hours);

replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (self_emp==1 | self_emp==2) & e9>=g13_7  & e8==4 & e9~=. & g13_7~=.; *(wage higher than self-emp profits);
replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (self_emp==1 | self_emp==2) & (e9+e9)>=g13_7  & e8==3 & e9~=. & g13_7~=.; 
replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (self_emp==1 | self_emp==2) & (e9+e9+e9+e9)>=g13_7  & e8==2 & e9~=. & g13_7~=.;
replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (self_emp==1 | self_emp==2) & (e9*30)>=g13_7  & e8==1 & e9~=. & g13_7~=.;
replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & e9>=i28  & e8==2 & e9~=. & i28~=.; *(wage equal to or higher than casual earnings);
replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & (e9/2)>=i28  & e8==3 & e9~=. & i28~=.; 
replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & (e9/4)>=i28  & e8==4 & e9~=. & i28~=.;
replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & (e9*5)>=i28  & e8==1 & e9~=. & i28~=.;
replace lfemployed=1 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & i25==1;

replace lfemployed=2 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (self_emp==1 | self_emp==2) & e9<g13_7  & e8==4 & e9~=. & g13_7~=.; *(wage lower than self-emp profits);
replace lfemployed=2 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (self_emp==1 | self_emp==2) & (e9+e9)<g13_7  & e8==3 & e9~=. & g13_7~=.; 
replace lfemployed=2 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (self_emp==1 | self_emp==2) & (e9+e9+e9+e9)<g13_7  & e8==2 & e9~=. & g13_7~=.;
replace lfemployed=2 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (self_emp==1 | self_emp==2) & (e9*20)<g13_7  & e8==1 & e9~=. & g13_7~=.;

replace lfemployed=3 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & e9<i28  & e8==2 & e9~=. & i28~=.; *(wage lower than casual earnings);
replace lfemployed=3 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & (e9/2)<i28  & e8==3 & e9~=. & i28~=.; 
replace lfemployed=3 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & (e9/4)<i28  & e8==4 & e9~=. & i28~=.;
replace lfemployed=3 if lfemployed==. & (wage_emp==1 | wage_emp==2) & (casual_emp==1 | casual_emp==2) & (e9*5)<i28  & e8==1 & e9~=. & i28~=.;

replace lfemployed=2 if lfemployed==. & (self_emp==1 | self_emp==2) & (casual_emp==1 | casual_emp==2) & (g13_7)/4>=i28 & g13_7~=. & i28~=.; *(self-emp profits equal or higher to casual earnings);
replace lfemployed=3 if lfemployed==. & (self_emp==1 | self_emp==2) & (casual_emp==1 | casual_emp==2) & (g13_7)/4<i28 & g13_7~=. & i28~=.; *(self-emp profits lower than casual earnings);
label values lfemployed lfemployedv;
label define lfemployedv 1 "wage workers" 2 "self-employed" 3 "casual workers";


**UNEMPLOYED**;

gen broad_unemp=.;
label variable broad_unemp "broadly defined unemployed";
replace broad_unemp=1 if f7==1 & employed==. & f8_1==1; *(Want a job, are not employed and are available for work in conventional working hours); 

gen actsearch_unemp=.;
label variable actsearch_unemp "active searching unemployed";
replace actsearch_unemp=1 if broad_unemp==1 & f19==1; *(Travelled to look for work);
replace actsearch_unemp=1 if actsearch_unemp==. & broad_unemp==1 & f29_6==1; *(Went to factories and waited outside);
replace actsearch_unemp=1 if actsearch_unemp==. & broad_unemp==1 & f29_7==1; *(Knocked on factory gates or visited homes and shops);
replace actsearch_unemp=1 if actsearch_unemp==. & broad_unemp==1 & f29_8==1; *(Visited employment agencies);
replace actsearch_unemp=1 if actsearch_unemp==. & broad_unemp==1 & f29_9==1; *(Phoned old employers);
replace actsearch_unemp=1 if actsearch_unemp==. & broad_unemp==1 & f29_10==1; *(Waited on the side of the road for jobs);
replace actsearch_unemp=1 if actsearch_unemp==. & broad_unemp==1 & f29_1==1 & f2==1; *(Looked in newspapers and believed this was the best way to get a job);
replace actsearch_unemp=1 if actsearch_unemp==. & broad_unemp==1 & f29_11==1 & f2==11; *(Looked on noticeboards and believed this was the best way to get a job);

gen networkex_unemp=.;
label variable networkex_unemp "exclusively networking searching unemployed";
replace networkex_unemp=1 if broad_unemp==1 & actsearch_unemp~=1 & f29_2==1; *(unemployed, not classified as searching but relying on household members to tell them about jobs);
replace networkex_unemp=1 if networkex_unemp==. & broad_unemp==1 & actsearch_unemp~=1 & f29_3==1; *(unemployed, not classified as searching but relying on friends/family from different households to tell them about jobs);
replace networkex_unemp=1 if networkex_unemp==. & broad_unemp==1 & actsearch_unemp~=1 & f29_4==1; *(unemployed, not classified as searching but relying on household members to get then a job);
replace networkex_unemp=1 if networkex_unemp==. & broad_unemp==1 & actsearch_unemp~=1 & f29_5==1; *(unemployed, not classified as searching but relying on friends/family from different households to get them a job);

gen marg_unemp=.;
label variable marg_unemp "marginalised unemployed";
replace marg_unemp=1 if broad_unemp==1 & actsearch_unemp~=1 & networkex_unemp~=1; *(broadly classified as unemployed but not looking for job);

gen int_unemp=.;
label variable int_unemp "intermediate category of unemployed";
replace int_unemp=1 if actsearch_unemp==1 | networkex_unemp==1;


** LABOUR FORCE PARTICIPANTS**;

gen brlfparticipant=.;
label variable brlfparticipant "broadly defined labour force participant";
replace brlfparticipant=1 if employed~=.;
replace brlfparticipant=2 if brlfparticipant==. & broad_unemp==1.;

gen stlfparticipant=.;
label variable stlfparticipant "strictly defined labour force participant";
replace stlfparticipant=1 if employed~=.;
replace stlfparticipant=2 if stlfparticipant==. & actsearch_unemp==1.;

gen intlfparticipant=.;
label variable intlfparticipant "intermediate definition labour force participant";
replace intlfparticipant=1 if employed~=.;
replace intlfparticipant=2 if intlfparticipant==. & int_unemp==1;


**NON LABOUR FORCE PARTICIPANTS**;


gen brnonlfparticipant=.;
label variable brnonlfparticipant "broadly defined non labour force participant";
replace brnonlfparticipant=1 if brlfparticipant==. & h3==2; *(not in the labour force and say they do not want work);

gen stnonlfparticipant=.;
label variable stnonlfparticipant "strictly defined non labour force participant";
replace stnonlfparticipant=1 if stlfparticipant==. & h3==2; *(not in the labour force, and say they do not want work);

gen intnonlfparticipant=.;
label variable intnonlfparticipant "intermediate definition: non labour force participant";
replace intnonlfparticipant=1 if intlfparticipant==. & h3==2; *(not in the labour force and say they do not want work);

gen brlabourmarketstatus=.;
label variable brlabourmarketstatus "labour market status (broad)";
replace brlabourmarketstatus=1 if lfemployed~=.;
replace brlabourmarketstatus=2 if brlabourmarketstatus==. & broad_unemp==1;
replace brlabourmarketstatus=3 if brnonlfparticipant==1;
replace brlabourmarketstatus=4 if brlabourmarketstatus==.;
label values brlabourmarketstatus brlabourmarketstatusv;
label define brlabourmarketstatusv 1 "employed" 2 "brunemp" 3 "non-LFP" 4 "missing";


gen lmstatus1=.;
label variable lmstatus "labour force categories";
replace lmstatus1=1 if lfemployed==1;
replace lmstatus1=2 if lfemployed==2;
replace lmstatus1=3 if lfemployed==3;
replace lmstatus1=4 if actsearch_unemp==1;
replace lmstatus1=5 if networkex_unemp==1;
replace lmstatus1=6 if marg_unemp==1;
replace lmstatus1=6 if lmstatus1==. & broad_unemp==1;
replace lmstatus1=7 if brnonlfparticipant==1;
label values lmstatus1 lmstatus1v;
label define lmstatus1v 1 "wage-emp" 2 "self-emp" 3 "casual-emp" 4 "search-unem" 5 "networksearch-unem" 6 "marginalised-unem" 7 "nonlfparticipant";


**EXPANDED DEFINITION OF EMPLOYMENT**;

gen wageemployedexp=.;
label variable wageemployedexp "wage employed - extra";
replace wageemployedexp=1 if brlabourmarketstatus==4 & e1==1 & h1!=2 & f5!=2; *(those not in the labour force so far, but who said they were employed as wage workers)*;

gen selfempexp=.;
label variable selfempexp "self employed - extra";
replace selfempexp=1 if brlabourmarketstatus==4 & wageemployedexp~=1 & f6==1 & h2!=2 &f6!=2; *(those not in the labour force so far - and did not qualify as employed above - but who said they were self-employed)*;

gen broad_unempexp=.;
label variable broad_unempexp "broad unemployed - extra";
replace broad_unempexp=1 if brlabourmarketstatus==4 & wageemployedexp~=1 & selfempexp~=1 & h1==2 & h2==2 & h3==1 & f5==2 & f6==2 & f7==1 & ((f8_1==1 | f8_2==1 | f8_3==1) | (f8_1==. & f8_2==. & f8_3==.)); *(those not in the labour force according to our definition - and who did not qualify as employed or selfemployed above - but who consistently said they did not have employment and wanted a job)*;

gen brnonlfparticipantexp=.;
label variable brnonlfparticipant "broadly defined non labour force participant - extra";
replace brnonlfparticipantexp=1 if brlabourmarketstatus==4 & wageemployedexp~=1 & selfempexp~=1 & broad_unempexp~=1 & h4~=. & h3~=1; *(those not in the labour force according to our definition - and who did not qualify as employed or unemployed under the extended definition - but who gave reasons for not wanting a job)*;

gen brlabourmarketstatusexp=.;
replace brlabourmarketstatusexp=1 if brlabourmarketstatus==1;
replace brlabourmarketstatusexp=1 if brlabourmarketstatusexp==. & (wageemployedexp==1 | selfempexp==1);
replace brlabourmarketstatusexp=2 if brlabourmarketstatusexp==. & brlabourmarketstatus==2;
replace brlabourmarketstatusexp=2 if brlabourmarketstatusexp==. & broad_unempexp==1;
replace brlabourmarketstatusexp=3 if brlabourmarketstatusexp==. & brlabourmarketstatus==3;
replace brlabourmarketstatusexp=3 if brlabourmarketstatusexp==. & brnonlfparticipantexp==1;
label values brlabourmarketstatusexp brlabourmarketstatusexpv;
label define brlabourmarketstatusexpv 1 "employed" 2 "brunemp" 3 "non-LFP";

gen lmstatus2=.;
label variable lmstatus2 "alternative labour force categories";
replace lmstatus2=1 if lfemployed==1 | wageemployedexp==1;
replace lmstatus2=2 if lfemployed==2 | selfempexp==1;
replace lmstatus2=3 if lfemployed==3;
replace lmstatus2=4 if actsearch_unemp==1;
replace lmstatus2=5 if networkex_unemp==1;
replace lmstatus2=6 if marg_unemp==1;
replace lmstatus2=6 if lmstatus2==. & broad_unempexp==1;
replace lmstatus2=7 if brnonlfparticipant==1 | brnonlfparticipantexp==1;
label values lmstatus2 lmstatus2v;
label define lmstatus2v 1 "wage-emp" 2 "self-emp" 3 "casual-emp" 4 "search-unem" 5 "networksearch-unem" 6 "marginalised-unem" 7 "nonlfparticipant";

gen broadu1=.;
replace broadu1=1 if lmstatus1==1;
replace broadu1=1 if lmstatus1==2;
replace broadu1=1 if lmstatus1==3;
replace broadu1=2 if lmstatus1==4;
replace broadu1=2 if lmstatus1==5;
replace broadu1=2 if lmstatus1==6;


gen strictu1=.;
replace strictu1=1 if lmstatus1==1;
replace strictu1=1 if lmstatus1==2;
replace strictu1=1 if lmstatus1==3;
replace strictu1=2 if lmstatus1==4;

gen broadu2=.;
replace broadu2=1 if lmstatus2==1;
replace broadu2=1 if lmstatus2==2;
replace broadu2=1 if lmstatus2==3;
replace broadu2=2 if lmstatus2>3 & lmstatus2<7 & lmstatus2!=.;


gen strictu2=.;
replace strictu2=1 if lmstatus2==1;
replace strictu2=1 if lmstatus2==2;
replace strictu2=1 if lmstatus2==3;
replace strictu2=2 if lmstatus2>3 & lmstatus2<5 & lmstatus2!=.;


/*

gen race2=a2;
replace race2=. if a2>2;
label values race2 race2v;
label define race2v 1 "African" 2 "Coloured";

recode q4adult *=86 if q4adult==1914;
recode q4adult *=76 if q4adult==1924;
recode q4adult *=75 if q4adult==1925;
recode q4adult *=71 if q4adult==1929;
recode q4adult *=70 if q4adult==1930;
recode q4adult *=68 if q4adult==1932;
recode q4adult *=67 if q4adult==1933;
recode q4adult *=66 if q4adult==1934;
recode q4adult *=65 if q4adult==1935;
recode q4adult *=64 if q4adult==1936;
recode q4adult *=63 if q4adult==1937;
recode q4adult *=62 if q4adult==1938;
recode q4adult *=61 if q4adult==1939;
recode q4adult *=60 if q4adult==1940;
recode q4adult *=59 if q4adult==1941;
recode q4adult *=58 if q4adult==1942;
recode q4adult *=57 if q4adult==1943;
recode q4adult *=56 if q4adult==1944;
recode q4adult *=55 if q4adult==1945;
recode q4adult *=54 if q4adult==1946;
recode q4adult *=53 if q4adult==1947;
recode q4adult *=52 if q4adult==1948;
recode q4adult *=51 if q4adult==1949;
recode q4adult *=50 if q4adult==1950;
recode q4adult *=49 if q4adult==1951;
recode q4adult *=48 if q4adult==1952;
recode q4adult *=47 if q4adult==1953;
recode q4adult *=46 if q4adult==1954;
recode q4adult *=45 if q4adult==1955;
recode q4adult *=44 if q4adult==1956;
recode q4adult *=43 if q4adult==1957;
recode q4adult *=42 if q4adult==1958;
recode q4adult *=41 if q4adult==1959;
recode q4adult *=40 if q4adult==1960;
recode q4adult *=39 if q4adult==1961;
recode q4adult *=38 if q4adult==1962;
recode q4adult *=37 if q4adult==1963;
recode q4adult *=36 if q4adult==1964;
recode q4adult *=35 if q4adult==1965;
recode q4adult *=34 if q4adult==1966;
recode q4adult *=33 if q4adult==1967;
recode q4adult *=32 if q4adult==1968;
recode q4adult *=31 if q4adult==1969;
recode q4adult *=30 if q4adult==1970;
recode q4adult *=29 if q4adult==1971;
recode q4adult *=28 if q4adult==1972;
recode q4adult *=27 if q4adult==1973;
recode q4adult *=26 if q4adult==1974;
recode q4adult *=25 if q4adult==1975;
recode q4adult *=24 if q4adult==1976;
recode q4adult *=23 if q4adult==1977;
recode q4adult *=22 if q4adult==1978;
recode q4adult *=21 if q4adult==1979;
recode q4adult *=20 if q4adult==1980;
recode q4adult *=19 if q4adult==1981;
recode q4adult *=18 if q4adult==1982;
recode q4adult *=. if q4adult==254;
recode q4adult *=. if q4adult==1983;
recode q4adult *=. if q4adult==1986;

gen empchance=.;
replace empchance=1 if lmstatus1<4 & lmstatus1!=.;
replace empchance=0 if lmstatus1>3 & lmstatus1!=.;

gen gend=.;
replace gend=1 if gender==1;
replace gend=0 if gender==2;
replace gend=1 if gend==. & q3adult==1;
replace gend=0 if gend==. & q3adult==2;

gen age=a2;
replace age=q4adult if age==.;

probit empchance gend a1;
predict yhat1;  */;




