#delimit;

clear all;
set mem 400m;


*Generate a Gross Total Monthly income for each adult*;
*Jolene Skordis, 01-10-2002, building on Matthew Welch's file 20-02-2002, Ver 2.0*;

*log using "C:\logfiles\mplain\adultinc_gross.smcl", replace*;



use "C:\Stata Mitchell's Plain\Data\Phase 2\data\stata 7\Adult_All_06_07.dta", clear;

merge hhid pcode using "C:\Stata Mitchell's Plain\Data\Phase 2\data\stata 7\householdmodule_All_06_07.dta";

*drop _merge;

*First we need to fix up some wages for E9 which were either not captured or miscaptured;
replace e9=	350	if hhid==	20	& pcode==	2	;
replace e9=	1500	if hhid==	61	& pcode==	5	;
replace e9=	3355	if hhid==	64	& pcode==	4	;
replace e9=	600	if hhid==	650	& pcode==	1	;
replace e9=	3000	if hhid==	831	& pcode==	2	;
replace e9=	417	if hhid==	840	& pcode==	2	;
replace e9=	2000	if hhid==	1350	& pcode==	1	;
replace e9=	400	if hhid==	1377	& pcode==	2	;

*Now we need to allocate those missing values from e8, we have looked at the means and decided how to categorise them;
*replace e8=	350	if hhid==	20	& pcode==	2	;
*replace e8=	1500	if hhid==	61	& pcode==	5	;
*replace e8=	3355	if hhid==	64	& pcode==	4	;
*replace e8=	600	if hhid==	650	& pcode==	1	;

*FIRST JOB SECTION, questions E3-E29*;

*First we need to ensure that e19 has as few missing values as possible.  Where values are missing we will replace them with e9 if e9 is gross and not missing;
*To do this we are going to make use of three things, a derived variable from E19_2-10, E9 variables that are gross and E19_1 measures that are not missing and not zero;

*Generating the derived variable;

egen e19_1_gmderive=rsum(e19_2- e19_10);		*e19 add up net + deductions to get a gross value*;

*Generating the gross variable for e9;

gen e9gross=.;
replace e9gross=e9 if e9~=.&e10==1;

*Now putting all of these together to make as complete an e19 as possible;

gen e19complete=.;
replace e19complete=e19_1 if e19_1>0&e19_1~=.;
replace e19complete=e9gross if e19complete==.&e9gross~=.;
replace e19complete=e19_1_gmderive if e19complete==.&e19_1_gmderive>0&e19_1_gmderive~=.&e19_10~=.;

*Using the frequency given in E8, we are going to convert e19complete to a monthly wage.  Remember that E1==1 for people answering this section;

gen e19grossmonth=.;
replace e19grossmonth=e19complete if e8==4;  		*already monthly*;
replace e19grossmonth=e19complete*21 if e8==1;		*daily to monthly, allowing for weekends and public holidays, south africans work an ave of 21.16 days/month;*;
replace e19grossmonth=e19complete*4 if e8==2;		*weekly to monthly*;
replace e19grossmonth=e19complete*2 if e8==3;		*fortnightly to monthly*;

label var e19grossmonth "First job - Gross monthly income from wages (derived)";


*Now work out the total monthly gross OVERTIME*;

gen e16overtime=.;
replace e16overtime=e16*e17;		*generate gross monthly overtime earned*;
*We are assuming that respondents gave accurate numbers of hours and their overtime pay before tax;
label var e16overtime "First job - Gross monthly overtime (derived)";


*Generate monthly bonus payments, peice rates etc from question E18;

*make some assumptions here about bonuses etc-some of these values are too high and indicate a yearly value was quoted;

*BONUS PAYMENTS;
gen e18bonus=.;
replace e18bonus= e18_1_2 if  e18_1_2>0 & e18_1_2<=(e19grossmonth*0.25) & e18_1_2~=.;
replace e18bonus=(e18_1_2/12) if e18_1_2>(e19grossmonth*0.25) & e18_1_2~=.;
label var e18bonus "Derived monthly bonus from - job";

*PIECE RATE PAYMENTS;
gen e18piece=.;
replace e18piece= e18_2_2 if  e18_2_2>0 & e18_2_2<=(e19grossmonth*0.25) & e18_2_2~=.;
replace e18piece=(e18_2_2/12) if e18_2_2>(e19grossmonth*0.25) & e18_2_2~=.;
label var e18piece "Derived monthly piece rate payments - first job";

*SHARE OF PROFITS;
gen e18profits=.;
replace e18profits= e18_3_2 if  e18_3_2>0 & e18_3_2<=(e19grossmonth*0.25) & e18_3_2~=.;
replace e18profits=(e18_3_2/12) if e18_3_2>(e19grossmonth*0.25) & e18_3_2~=.;
label var e18profits "Derived monthly share of profits - first job";

*BONUS WHEN BUSINESS IS DOING WELL;
gen e18wellbonus=.;
replace e18wellbonus= e18_4_2 if e18_4_2>0 & e18_4_2<=(e19grossmonth*0.25)& e18_4_2~=.;
replace e18wellbonus=(e18_4_2/12) if e18_4_2>(e19grossmonth*0.25) & e18_4_2~=.;
label var e18wellbonus "Derived monthly bonus if business is doing well - first job";

*PRODUCTIVITY PAY;
gen e18productivity=.;
replace e18productivity= e18_5_2 if  e18_5_2>0 & e18_5_2<=(e19grossmonth*0.25) & e18_5_2~=.;
replace e18productivity=(e18_5_2/12) if e18_5_2>(e19grossmonth*0.25) & e18_5_2~=.;
label var e18productivity "Derived productivity pay - first job";


*Assumption here is that if either of these payments is greater than 25% of the gross monthly wage in e19 then it is prob.a yearly figure;


egen e18totalbonus=rsum(e18bonus e18piece e18profits e18wellbonus e18productivity);   *generates a total BONUS payment variable from the components of E18;

label var e18totalbonus "First job - Gross monthly bonus payments (derived)";


*Generate total wage income =gross monthly wage income + monthly overtime pay + monthly bonus payments etc;

egen totmwinc=rsum(e19grossmonth e16overtime  e18totalbonus);
replace totmwinc=. if totmwinc==0;  *get rid of the zeros created by rsum, those who did not earn wages should be missing;
replace totmwinc=. if emergency==1; *the emergency information is net so we do not include it -how do we deal with these?*;

assert totmwinc~=0;  *Check that all zeros created by the rowsum command have been set back to missing;


*END OF TOTAL WAGE INCOME CALCULATION FOR THE FIRST JOB;

*NOW THE SAME AS ABOVE BUT FOR THE SECOND JOB*;


*First we need to ensure that e46 has as few missing values as possible.  Where values are missing we will replace them with e9 if e9 is gross and not missing;
*To do this we are going to make use of three things, a derived variable from e46 _2-10, e36 variables that are gross and e46_1 measures that are not missing and not zero;

*Generating the derived variable;

egen e46_1_gmderive=rsum(e46_2- e46_10);		*e46 add up net + deductions to get a gross value*;

*Generating the gross variable for e36;

gen e36gross=.;
replace e36gross=e36 if e36~=.& e37==1;

*Now putting all of these together to make as complete an e46 as possible;

gen e46complete=.;
replace e46complete=e46_1 if e46_1>0 & e46_1~=.;
replace e46complete=e36gross if e46complete==. & e36gross~=.;
replace e46complete=e46_1_gmderive if e46complete==. & e46_1_gmderive>0 & e46_1_gmderive~=. & e46_10~=.;

*Using the frequency given in e35, we are going to convert e46complete to a monthly wage.  Remember that e1==1 for people answering this section;

gen e46grossmonth=.;
replace e46grossmonth=e46complete if e35==4;  		*already monthly*;
replace e46grossmonth=e46complete*21 if e35==1;		*daily to monthly, allowing for weekends and public holidays, south africans work an ave of 21.16 days/month;*;
replace e46grossmonth=e46complete*4 if e35==2;		*weekly to monthly*;
replace e46grossmonth=e46complete*2 if e35==3;		*fortnightly to monthly*;

label var e46grossmonth "Second job - Gross monthly income from wages (derived)";


*Now work out the total monthly gross OVERTIME*;

gen e43overtime=.;
replace e43overtime=e43*e44;		*generate gross monthly overtime earned*;
*We are assuming that respondents gave accurate numbers of hours and their overtime pay before tax;
label var e43overtime "Second job - Gross monthly overtime (derived)";

*Generate monthly bonus payments, peice rates etc from question E45;

*make some assumptions here about bonuses etc-some of these values are too high and indicate a yearly value was quoted;

*BONUS PAYMENTS;
gen e45bonus=.;
replace e45bonus= e45_1_2 if  e45_1_2>0 & e45_1_2<=(e46grossmonth*0.25) & e45_1_2~=.;
replace e45bonus=(e45_1_2/12) if e45_1_2>(e46grossmonth*0.25) & e18_1_2~=.;
label var e45bonus "Derived monthly bonus - second job";

*PIECE RATE PAYMENTS;
gen e45piece=.;
replace e45piece= e45_2_2 if  e45_2_2>0 & e45_2_2<=(e46grossmonth*0.25) & e45_2_2~=.;
replace e45piece=(e45_2_2/12) if e45_2_2>(e46grossmonth*0.25) & e18_2_2~=.;
label var e45piece "Derived monthly piece rate payments - second job";

*SHARE OF PROFITS;
gen e45profits=.;
replace e45profits= e45_3_2 if  e45_3_2>0 & e45_3_2<=(e46grossmonth*0.25) & e45_3_2~=.;
replace e45profits=(e45_3_2/12) if e45_3_2>(e46grossmonth*0.25) & e45_3_2~=.;
label var e45profits "Derived monthly share of profits - second job";

*BONUS WHEN BUSINESS IS DOING WELL;
gen e45wellbonus=.;
replace e45wellbonus= e45_4_2 if e45_4_2>0 & e45_4_2<=(e46grossmonth*0.25)& e45_4_2~=.;
replace e45wellbonus=(e45_4_2/12) if e45_4_2>(e46grossmonth*0.25) & e45_4_2~=.;
label var e45wellbonus "Derived monthly bonus if business is doing well - second job";

*PRODUCTIVITY PAY;
gen e45productivity=.;
replace e45productivity= e45_5_2 if  e45_5_2>0 & e45_5_2<=(e46grossmonth*0.25) & e45_5_2~=.;
replace e45productivity=(e45_5_2/12) if e45_5_2>(e46grossmonth*0.25) & e45_5_2~=.;
label var e45productivity "Derived productivity pay - second job";


*Assumption here is that if either of these payments is greater than 25% of the gross monthly wage in e46 then it is prob.a yearly figure;


egen e45totalbonus=rsum(e45bonus e45piece e45profits e45wellbonus e45productivity);   *generates a total BONUS payment variable from the components of E18;

label var e45totalbonus "Second job - Gross monthly bonus payments (derived)";


*Generate a total wage income =sum wages + OVERTIME + BONUS*;

egen totmwinc2=rsum(e46grossmonth e43overtime  e45totalbonus);
replace totmwinc2=. if totmwinc2==0;  *get rid of the zeros created by rsum, those who did not earn wages should be missing;
replace totmwinc2=. if emergency==1; *the emergency information is net so we do not include it -how do we deal with these?*;

assert totmwinc2~=0;  *Check that all zeros created by the rowsum command have been set back to missing;

*replace totmwinc2=. if E1==2 | E2==2;  *Get rid of the zeros created by rsum, those who did not earn wages should be missing*;
*replace totmwinc2=. if totmwinc2==0 & PROXY~=.; /*proxy wages were often not given, make sure that the missings are not 0's*/;
*The two steps above has not been done in this iteration - should they be?? If so they should be done for the first job too*;*;

label var totmwinc2 "Total monthly gross wage earnings-second job";


*NOW TO MAKE A TOTAL GROSS WAGE VARIABLE FROM ALL WAGE JOBS;

egen allwageinc=rsum(totmwinc totmwinc2);

replace allwageinc=. if totmwinc==. & totmwinc2==.;  *egen rsum makes .=0 correct this*;

label var allwageinc "Gross monthly wage income-all jobs (derived)";

assert allwageinc~=0;

sort hhid pcode;

*NOW TO ADD IN ALL THE OTHER SOURCES OF INCOME FROM SECTIONS G, I AND L;

*ADDING INCOME FROM OWN BUSINESS USING TAKE-HOME PROFIT - SEE QUESTIONNAIRE FOR NOTES ON WHY;

gen g13_8temp=g13_8 if g13_8~=. & g13_8~=0;

egen step1=rsum(allwageinc g13_8temp);

replace step1=. if allwageinc==. & g13_8temp==.;

assert step1~=0;


*ADDING INCOME FROM CASUAL WORK IE FROM I15 if I1==1*/;

gen i15temp=i15 if i15~=. & i15~=0;

egen step2=rsum(step1 i15temp);

replace step2=. if step1==. & i15temp==.;

assert step2~=0;


*NOW ADDING THOSE PEOPLE WHO SAY THERE IS CASUAL INCOME THEY HAVE NOT YET DISCLOSED;

gen i30_2temp=i30_2 if i30_2~=. & i30_2~=0;

egen step2b=rsum(step2 i30_2temp);

replace step2b=. if step2==. & i30_2temp==.;

assert step2b~=0;


*We will not be using data from the emergency module for methodological reasons so some of the following steps will not be conducted;;
*gen I32temp=I32 if I32~=0;  /*emergency module casual work I32*/;
*egen step2_1=rsum(step2 I32temp);
*replace step2_1=. if step2==. & I32temp==.;
*gen I34temp=I34 if I34~=0;  /*emergency module other work I34*/;
*egen step2_2=rsum(step2_1 I34temp);
*replace step2_2=. if step2_1==. & I34temp==.;

*NOW ADDING INCOME FROM GRANTS, INVESTMENTS AND OTHER SIMILAR INCOME;

*FIRST, MONEY FROM GRANTS;

*L13_1 to L13_10 converted to monthly*/;

gen l13_1_1temp=.;
replace l13_1_1temp=l13_1_1 if l13_1_2==3;
replace l13_1_1temp=(l13_1_1/2) if l13_1_2==4; 
replace l13_1_1temp=l13_1_1 if l13_1_2==. & l13_1_1~=0; /*assume if l13_1_2=. that monthly*/;
replace l13_1_1temp=. if l13_1_1temp==0;
assert l13_1_1temp~=0;

gen l13_2_1temp=.;
replace l13_2_1temp=l13_2_1 if l13_2_2==3;
replace l13_2_1temp=(l13_2_1/2) if l13_2_2==4; 
replace l13_2_1temp=l13_2_1 if l13_2_2==. & l13_2_1~=0; /*assume if l13_2_2=. that monthly*/;
replace l13_2_1temp=. if l13_2_1temp==0;
assert l13_2_1temp~=0;

gen l13_3_1temp=.;
replace l13_3_1temp=l13_3_1 if l13_3_2==3;
replace l13_3_1temp=(l13_3_1/2) if l13_3_2==4; 
replace l13_3_1temp=l13_3_1 if l13_3_2==. & l13_3_1~=0; /*assume if l13_3_2=. that monthly*/;
replace l13_3_1temp=. if l13_3_1temp==0;
assert l13_3_1temp~=0;

gen l13_4_1temp=.;
replace l13_4_1temp=l13_4_1 if l13_4_2==3;
replace l13_4_1temp=(l13_4_1/2) if l13_4_2==4; 
replace l13_4_1temp=l13_4_1 if l13_4_2==. & l13_4_1~=0; /*assume if l13_4_2=. that monthly*/;
replace l13_4_1temp=. if l13_4_1temp==0;
assert l13_4_1temp~=0;

gen l13_5_1temp=.;
replace l13_5_1temp=l13_5_1 if l13_5_2==3;
replace l13_5_1temp=(l13_5_1/2) if l13_5_2==4; 
replace l13_5_1temp=l13_5_1 if l13_5_2==. & l13_5_1~=0; /*assume if l13_5_2=. that monthly*/;
replace l13_5_1temp=. if l13_5_1temp==0;
assert l13_5_1temp~=0;

gen l13_6_1temp=.;
replace l13_6_1temp=l13_6_1 if l13_6_2==3;
replace l13_6_1temp=(l13_6_1/2) if l13_6_2==4;
replace l13_6_1temp=l13_6_1 if l13_6_2==. & l13_6_1~=0; /*assume if L13_6_2=. that monthly*/;
replace l13_6_1temp=. if l13_6_1temp==0;
assert l13_6_1temp~=0;

gen l13_7_1temp=.;
replace l13_7_1temp=l13_7_1 if l13_7_2==3;
replace l13_7_1temp=(l13_7_1/2) if l13_7_2==4;
replace l13_7_1temp=l13_7_1 if l13_7_2==. & l13_7_1~=0; /*assume if L13_7_2=. that monthly*/;
replace l13_7_1temp=. if l13_7_1temp==0;
assert l13_7_1temp~=0;

gen l13_8_1temp=.;
replace l13_8_1temp=l13_8_1 if l13_8_2==3;
replace l13_8_1temp=(l13_8_1/2) if l13_8_2==4;
replace l13_8_1temp=l13_8_1 if l13_8_2==. & l13_8_1~=0; /*assume if l13_8_2=. that monthly*/;
replace l13_8_1temp=. if l13_8_1temp==0;
assert l13_8_1temp~=0;

gen l13_9_1temp=.;
replace l13_9_1temp=l13_9_1 if l13_9_2==3;
replace l13_9_1temp=(l13_9_1/2) if l13_9_2==4;
replace l13_9_1temp=l13_9_1 if l13_9_2==. & l13_9_1~=0; /*assume if l13_9_2=. that monthly*/;
replace l13_9_1temp=. if l13_9_1temp==0;
assert l13_9_1temp~=0;

gen l13_10_1temp=.;
replace l13_10_1temp=l13_10_1 if l13_10_2==3;
replace l13_10_1temp=(l13_10_1/2) if l13_10_2==4;
replace l13_10_1temp=l13_10_1 if l13_10_2==. & l13_10_1~=0; /*assume if l13_10_2=. that monthly*/;
replace l13_10_1temp=. if l13_10_1temp==0;
assert l13_10_1temp~=0;

egen step3=rsum(l13_1_1temp - l13_10_1temp);

replace step3=. if l13_1_1temp==. & l13_2_1temp==. & l13_3_1temp==. & l13_4_1temp==. & l13_5_1temp==. & l13_6_1temp==. & 
l13_7_1temp==. & l13_8_1temp==. & l13_9_1temp==. & l13_10_1temp==.;

assert step3~=0;

egen step4=rsum(step2b step3);

replace step4=. if step2b==. & step3==.;

assert step4~=0;

*NOW MONEY FROM OTHER PEOPLE;

/*L15_1_1 to L15_3_1 if L14==1  money from other people we only want to include those from outside the hh 
so as not to double count incomes later for the hh i.e. L15_1 etc>=9*/;

gen l15_1_1temp=.;
replace l15_1_1temp=l15_1_1 if l15_1_1~=. & l15_1_1~=0 & l15_1>=9;

gen l15_2_1temp=.;
replace l15_2_1temp=l15_2_1 if l15_2_1~=. & l15_2_1~=0 & l15_2>=9;

gen l15_3_1temp=.;
replace l15_3_1temp=l15_3_1 if l15_3_1~=. & l15_3_1~=0 & l15_3>=9;

egen step5=rsum(l15_1_1temp - l15_3_1temp);

replace step5=. if l15_1_1temp==. & l15_2_1temp==. & l15_3_1temp==.;

assert step5~=0;

egen step6=rsum(step5 step4);

replace step6=. if step5==. & step4==.;

assert step6~=0;

*NOW FROM OTHER FORMS OF INCOME;
/*L16_1 to L16_3 Other forms of income*/;

gen l16_1_1temp=.;
replace l16_1_1temp=l16_1_1 if l16_1_1~=0 & l16_1_1~=.;

gen l16_2_1temp=.;
replace l16_2_1temp=l16_2_1 if l16_2_1~=0 & l16_2_1~=.;

gen l16_3_1temp=.;
replace l16_3_1temp=l16_3_1 if l16_3_1~=0 & l16_3_1~=.;

egen step7=rsum(l16_1_1temp - l16_3_1temp);

replace step7=. if l16_1_1temp==. & l16_2_1temp==. & l16_3_1temp==.;

assert step7~=0;

egen step8=rsum(step6 step7);

replace step8=. if step6==. & step7==.;

assert step8~=0;


rename step8 totalincome;

replace totalincome=. if proxy==2;  /*Proxy questionnaires often had no income info*/;

label var totalincome"Adult module: Total gross monthly income from all sources (derived)";

/*Monthly gross household income (derived)*/;
sort hhid;
egen hhtotminc=sum(totalincome),by( hhid);
replace hhtotminc=. if totalincome==. & hhtotminc==0;

*Matthews earlier notes, many of these still apply;
*note: E18 and E45 have some high values that indicate the resp. quoted a yearly and not an avg. monthly rate;
*note: for  E45_BONUS E18_BONUS assumption for 13th cheque is that if the bonus is 25% of or > than the wage then it must be a yearly figure so divide by 12;
*note: For E_TOTMINC TOTWAGE TOTWAGE2 see the assumptions made for the components E43_OVERTIME E16_OVERTIME E45_BONUS E18_BONUS;
*note: E43_OVERTIME E16_OVERTIME some of the values for E16 and E17 seem unlikely and have been removed for the totwage calculation;         

save "C:\Stata Mitchell's Plain\Skordis Welch\All_04_07_gross.dta", replace;



*log close*;







